@@ -4,6 +4,10 @@ from mongorm.database import Database
 from mongorm.document import Field
 from mongorm.utils import DotDict
 
-VERSION = (0, 4, 1)
+VERSION = (0, 4, 2)
 
-__all__ = ['VERSION', 'Database', 'Field', 'DotDict']
+
+class ValidationError(Exception):
+    pass
+
+__all__ = ['VERSION', 'Database', 'Field', 'DotDict', 'ValidationError']
